# Description
Example of testing the CupSodaSimulator for handling an invalid initial keyword argument.

# Code
```
import numpy as np
from pysb.examples.tyson_oscillator import model
from pysb.simulator.cupsoda import CupSodaSimulator


```
